"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const github_1 = require("../services/github");
const helpers_1 = require("../errors/helpers");
const fileHandler_1 = require("./fileHandler");
const ora = require("ora");
/**
 * Validate Github API token
 *
 * @param {String} token Github API token
 */
exports.validateToken = async (token, repo) => {
    github_1.initGithubService(token);
    try {
        const tokenValidateSpinner = ora('Validating Github API token.').start();
        const response = await github_1.validateTokenOnRepo(repo);
        if (response.status === 200) {
            tokenValidateSpinner.succeed('Github API token validated!');
        }
        else if (response.status === 500) {
            tokenValidateSpinner.fail('Something is wrong');
        }
        else {
            tokenValidateSpinner.fail('Invalid Github API token.');
        }
    }
    catch (error) {
        helpers_1.checkTypeAndAppropriateThrowCliError(error);
    }
};
/**
 * Download given file and store them on disk
 * @param {Object} fileObj File object containing information from where download and where to save
 * @param {String} fileObj.source Path to download file
 * @param {String} fileObj.destination Path to store downloaded file
 * @param {String} token Github API token
 */
exports.getConfigs = async (token, env, repo, service, branch) => {
    github_1.initGithubService(token);
    try {
        const responseContent = await github_1.getContentFromRepo(repo, service, branch);
        const folder = responseContent.data.find((folder) => {
            return folder.name === env;
        });
        const responseTree = await github_1.getGitTreeFromRepo(repo, folder.sha, branch);
        const files = responseTree.data.tree.filter((treeObject) => {
            return treeObject.type === 'blob';
        });
        const status = ora(`Downloading configuration file[s] for ${service}`).start();
        const resolvedFileStreams = await fileHandler_1.initiateStreams(files, github_1.getFileFromRepo);
        status.succeed();
        const commanderMessage = (stream) => {
            return ora(`Saving config file to ${stream.path}`).start();
        };
        const pipedFilesResponse = await fileHandler_1.pipeFiles(commanderMessage, resolvedFileStreams);
        return pipedFilesResponse.every((res) => res === true);
    }
    catch (error) {
        helpers_1.checkTypeAndAppropriateThrowCliError(error);
    }
};
